@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 #use warnings;
 
-our $VERSION = '0.5401';
+our $VERSION = '0.5402';
 
 use Carp;
 use Math::BigInt;
@@ -863,7 +863,7 @@ Math::FractionManip - Manipulate fractions
 
 =head1 VERSION
 
-version 0.5401
+version 0.5402
 
 =head1 SYNOPSIS
 
@@ -956,8 +956,6 @@ TAGS can equal 0 or one or more of the following:
 
 Control how the fraction is displayed.
 
-=over 8
-
 =item NORMAL
 
 Display in the #/# form.
@@ -978,8 +976,6 @@ The same as NORMAL but always includes the sign.
 
 Will let it be what ever the default value is at the time.
 
-=back
-
 =item REDUCE|NO_REDUCE|DEF_REDUCE
 
 Controls the automatic reduction of fraction after operations are
@@ -1008,24 +1004,44 @@ When the AUTO tag is set these tags will have NO effect.
 
 =item new
 
+The constructor.
+
 =item abs
 
+Overloaded for fractional arithmetic.
+
 =item add
 
+Overloaded for fractional arithmetic.
+
 =item cmp
 
+Overloaded for fractional arithmetic.
+
 =item div
 
+Overloaded for fractional arithmetic.
+
 =item mul
 
+Overloaded for fractional arithmetic.
+
 =item pow
 
+Overloaded for fractional arithmetic.
+
 =item sqrt
 
+Overloaded for fractional arithmetic.
+
 =item sub
 
+Overloaded for fractional arithmetic.
+
 =item modify_digits
 
+  modify_digits(NUM)
+
 =item reduce
 
 Return a reduced fraction but leave the original object untouched.
@@ -1063,10 +1079,6 @@ Return a list of the object tags.
 Return a list of the object tags. If a particular tag
 is set to read a default the default tag is returned instead.
 
-=back
-
-=over 4
-
 =item modify
 
 Modify the object.  Works almost the same as the new method
@@ -1101,8 +1113,6 @@ Return the default number of digits to return when doing
 floating point operations with BIG numbers, if set to undef
 Math::BigFloat will decide.
 
-  modify_digits(NUM)
-
 =back
 
 =head2 Default Sets
@@ -1222,7 +1232,7 @@ When you give it a number it will decide if it is small enough to be
 stored as a SMALL or if the fraction needs to converted to BIG.
 However, in order for it to recognize a big fraction the number needs to
 be in quotes. Thus,
-C<Math::FractionManip->new(7823495784957895478,781344567825678454)>
+C<Math::FractionManip-E<gt>new(7823495784957895478,781344567825678454)>
 will be stored as a SMALL with some of the digits lost.
 
 When calculating to SMALL numbers that results in a number that is too
@@ -1240,7 +1250,7 @@ turn it off.
 
 =head1 SEE ALSO
 
-The F<t/01-functions.t> program in this distribution
+The F<t/01-methods.t> program in this distribution
 
 =head1 AUTHOR
 
